local lv_draw = love.graphics.draw
local lv_print = love.graphics.print
local lv_printf = love.graphics.printf
local lv_newImage = love.graphics.newImage
local lv_setColor = love.graphics.setColor
local lv_rectangle = love.graphics.rectangle
local lv_getFPS = love.timer.getFPS

local glyphs = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz1234567890{}[]()<>$*-+=/#_%^@\\&|~?'\" !,.;:"

function createfixedwidthfont()
	local font = love.graphics.getFont()
	local h = font:getHeight()
	local w = font:getWidth("W") --widest letter
	local px,py = 100,100
	local lx,ly = math.ceil(px-w/2),math.ceil(py-h*0.75)
	local r,g,b,a,screen
	local letter = love.image.newImageData(w,h)
	local fontimage = love.image.newImageData((w+1)*glyphs:len()+1,h)
	
	local separator = love.image.newImageData(1,h)
	for i=0,h-1 do --generate yellow pixel line
		separator:setPixel(0,i,255,255,0,255) 
	end
	
	fontimage:paste(separator,0,0,0,0,1,h)
	for i=1,glyphs:len() do
		lv_setColor(0,0,0,255)
		lv_rectangle("fill",lx,ly,w,h) --black background for letter
		lv_setColor(255,255,255,255)
		lv_printf(glyphs:sub(i,i),px,py,0,"center") --letter
		
		screen = love.graphics.newScreenshot()
		letter:paste(screen,0,0,lx,ly,w,h) --cut it from screenshot
		--[
		for x=0,w-1 do --replace background with transparency
			for y=0,h-1 do
				r,g,b,a = letter:getPixel(x,y)
				letter:setPixel(x,y,255,255,255,r)
			end
		end
		--]]
		
		fontimage:paste(letter,(i-1)*w+i,0,0,0,w,h)
		fontimage:paste(separator,i*w+i,0,0,0,1,h) --yellow pixel line
	end
	
	generatedfontimage = love.graphics.newImage(fontimage)
	
	--[[
	local data = love.image.newEncodedImageData(generatedfontimage,"tga")
	love.filesystem.write("fixedwidthfont.tga",data) --save generated font
	--]]
end

function love.load()
	love.graphics.setBackgroundColor(128,128,128)
	defaultfont = love.graphics.newFont(18)
	love.graphics.setFont(defaultfont)
end

local once = true
function love.draw()
	if once then 
		once = not once
		createfixedwidthfont()
		fixedwidthfont = love.graphics.newImageFont(generatedfontimage,glyphs)
	end
	lv_draw(generatedfontimage,10,100)
	
	love.graphics.setFont(fixedwidthfont)
	lv_print("This is generated fixed width font.",10,200)
	
	love.graphics.setFont(defaultfont)
	lv_print("This is default font.",10,250)
	
	lv_print(lv_getFPS(),10,30)
end
